@@ -273,13 +273,13 @@ impl std::fmt::Display for Pattern {
     }
 }
 
-impl<'a, 'tree> PartialOrd for Match<'a, 'tree> {
+impl PartialOrd for Match<'_, '_> {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
         Some(self.cmp(other))
     }
 }
 
-impl<'a, 'tree> Ord for Match<'a, 'tree> {
+impl Ord for Match<'_, '_> {
     // Tree-sitter returns matches in the order that they terminate
     // during a depth-first walk of the tree. If multiple matches
     // terminate on the same node, those matches are produced in the
@@ -320,8 +320,8 @@ pub fn assert_query_matches(
     let tree = parser.parse(source, None).unwrap();
     let mut cursor = QueryCursor::new();
     let matches = cursor.matches(query, tree.root_node(), source.as_bytes());
-    pretty_assertions::assert_eq!(collect_matches(matches, query, source), expected);
-    pretty_assertions::assert_eq!(cursor.did_exceed_match_limit(), false);
+    pretty_assertions::assert_eq!(expected, collect_matches(matches, query, source));
+    pretty_assertions::assert_eq!(false, cursor.did_exceed_match_limit());
 }
 
 pub fn collect_matches<'a>(
